package suspendtest;

import javax.jms.JMSException;
import javax.jms.Message;
import javax.jms.MessageListener;
import javax.jms.TextMessage;
import javax.jms.TopicSubscriber;



public class TopicConsumer extends TopicClient implements MessageListener {
	protected boolean isAlive;
	private TopicSubscriber topicSubscriber;
	
	public TopicConsumer(String host) {
		super(host);
		System.out.println("-------- Created TopicConsumer --------");
		try {
			topicSubscriber = topicSession.createSubscriber(topic);
			topicSubscriber.setMessageListener(this);
			isAlive = true;
		} catch (JMSException e) {
			e.printStackTrace();
		}
	}

	@Override
	public void onMessage(Message message) {
		if (message instanceof TextMessage) {
			try {
				System.out.println("Received message " + ((TextMessage)message).getText());
			} catch (JMSException e) {
				e.printStackTrace();
			}
		}
		else {
			System.out.println("Received an untyped mesage as a terminator to a stream of messages.");
			isAlive = false;
		}
	}
	
	@Override
	public final void close() {
		try {
			topicSubscriber.close();
		} catch (JMSException e) {
			e.printStackTrace();
		}
		super.close();
		System.out.println("TopicConsumer closed");
	}

	public final boolean isAlive() {
		return isAlive;
	}

	/**
	 * block and receive messages whilst the consumer isAlive
	 */
	public final void receiveMessages() {
		System.out.println("TopicConsumer ready to receive messages...");
		while(isAlive) { // keep receiving messages
			try {
				Thread.sleep(100);
			} catch (InterruptedException e) {
				break; // interupted when the animating thread is closing
			}
		}
		close();
	}
	
	
	
	public static void main(String[] args) {
		if (args.length == 1) {
			TopicConsumer consumer = new TopicConsumer(args[0]);
			consumer.receiveMessages();
		}
		else {
			System.out.println("Usage: java -jar TopicConsumer.jar host");
		}
	}
	
}
