package suspendtest;

import javax.jms.DeliveryMode;
import javax.jms.JMSException;
import javax.jms.TopicPublisher;

public class TopicProducer extends TopicClient {
	private TopicPublisher topicPublisher;


	public TopicProducer(String host) {
		super(host);
		System.out.println("-------- Created TopicProducer --------");
		try {
			topicPublisher = topicSession.createPublisher(topic);
			topicPublisher.setDeliveryMode(DeliveryMode.NON_PERSISTENT);
		} catch (JMSException e) {
			e.printStackTrace();
		}
	}

	public final void sendMessage(String message) {
		if (message != null) {
			try {
				System.out.println("Sending message " + message);
				topicPublisher.publish(topicSession.createTextMessage(message));
				System.out.println("Sent message " + message);
			} catch (JMSException e) {
				e.printStackTrace();
			}
		}
		else { // message == null
			try {
	            // Send an un-typed message indicating end of messages.
				System.out.println("Sending an untyped mesage as a terminator to a stream of messages.");
				topicPublisher.publish(topicSession.createMessage());
			} catch (JMSException e) {
				e.printStackTrace();
			}
		}
	}
	
	@Override
	public final void close() {
		try {
			topicPublisher.close();
		} catch (JMSException e) {
			e.printStackTrace();
		}
		super.close();
		System.out.println("TopicProducer closed");
	}

	
	
	
	public static void main(String[] args) {
		if (args.length == 1) {
			TopicProducer producer = new TopicProducer(args[0]);
			for (int i = 0; i < 100000; i++) {
				producer.sendMessage("(" + i + ") Blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah!");
				try {
					Thread.sleep(100);
				} catch (InterruptedException e) {
					e.printStackTrace();
				}
			}
			producer.sendMessage(null); // terminate the message stream
		}
		else {
			System.out.println("Usage: java -jar TopicProducer.jar host");
		}
	}
	
}
